# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.0

([Full Changelog](https://github.com/visdesignlab/persist/compare/5ed90bee518fff9daf81df3fb927c143e0807e46...264ad73011e88db77c4b44a09fb1bf0de7363326))

### Enhancements made

- Rename extension to `persist_ext` [#58](https://github.com/visdesignlab/persist/pull/58) ([@kirangadhave](https://github.com/kirangadhave))
- Major features [#44](https://github.com/visdesignlab/persist/pull/44) ([@kirangadhave](https://github.com/kirangadhave))

### Other merged PRs

- feat(log-console): added  log console ext + integrated with global logger [#20](https://github.com/visdesignlab/persist/pull/20) ([@kirangadhave](https://github.com/kirangadhave))
- CI test probe [#19](https://github.com/visdesignlab/persist/pull/19) ([@kirangadhave](https://github.com/kirangadhave))
- Testing github actions [#18](https://github.com/visdesignlab/persist/pull/18) ([@kirangadhave](https://github.com/kirangadhave))
- testing actions [#15](https://github.com/visdesignlab/persist/pull/15) ([@kirangadhave](https://github.com/kirangadhave))
- Testing kernel comms [#1](https://github.com/visdesignlab/persist/pull/1) ([@kirangadhave](https://github.com/kirangadhave))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/visdesignlab/persist/graphs/contributors?from=2023-01-16&to=2023-06-25&type=c))

[@github-actions](https://github.com/search?q=repo%3Avisdesignlab%2Fpersist+involves%3Agithub-actions+updated%3A2023-01-16..2023-06-25&type=Issues) | [@kirangadhave](https://github.com/search?q=repo%3Avisdesignlab%2Fpersist+involves%3Akirangadhave+updated%3A2023-01-16..2023-06-25&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.1a2

([Full Changelog](https://github.com/kirangadhave/interactivede/compare/v1.0.1a1...48d65ad2d6ace997cf27bfc70dacd055b30ae862))

### Enhancements made

- Major features [#44](https://github.com/kirangadhave/interactivede/pull/44) ([@kirangadhave](https://github.com/kirangadhave))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/kirangadhave/interactivede/graphs/contributors?from=2023-04-26&to=2023-06-20&type=c))

[@kirangadhave](https://github.com/search?q=repo%3Akirangadhave%2Finteractivede+involves%3Akirangadhave+updated%3A2023-04-26..2023-06-20&type=Issues)

## 1.0.1a1

([Full Changelog](https://github.com/kirangadhave/interactivede/compare/5ed90bee518fff9daf81df3fb927c143e0807e46...5bf2effb4e84ecdcbe7bd32f662c6fbca1f636ea))

### Merged PRs

- feat(log-console): added log console ext + integrated with global logger [#20](https://github.com/kirangadhave/interactivede/pull/20) ([@kirangadhave](https://github.com/kirangadhave))
- CI test probe [#19](https://github.com/kirangadhave/interactivede/pull/19) ([@kirangadhave](https://github.com/kirangadhave))
- Testing github actions [#18](https://github.com/kirangadhave/interactivede/pull/18) ([@kirangadhave](https://github.com/kirangadhave))
- testing actions [#15](https://github.com/kirangadhave/interactivede/pull/15) ([@kirangadhave](https://github.com/kirangadhave))
- Testing kernel comms [#1](https://github.com/kirangadhave/interactivede/pull/1) ([@kirangadhave](https://github.com/kirangadhave))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/kirangadhave/interactivede/graphs/contributors?from=2023-01-16&to=2023-04-26&type=c))

[@github-actions](https://github.com/search?q=repo%3Akirangadhave%2Finteractivede+involves%3Agithub-actions+updated%3A2023-01-16..2023-04-26&type=Issues) | [@kirangadhave](https://github.com/search?q=repo%3Akirangadhave%2Finteractivede+involves%3Akirangadhave+updated%3A2023-01-16..2023-04-26&type=Issues)

## 1.0.1a0

No merged PRs

## 1.0.1

No merged PRs

## 1.0.0

No merged PRs

## 0.0.2

No merged PRs

## 0.0.1

([Full Changelog](https://github.com/kirangadhave/interactivede/compare/5ed90bee518fff9daf81df3fb927c143e0807e46...042266843526109ee99b2b7da6efdf28707a8ffa))

### Merged PRs

- CI test probe [#19](https://github.com/kirangadhave/interactivede/pull/19) ([@kirangadhave](https://github.com/kirangadhave))
- Testing github actions [#18](https://github.com/kirangadhave/interactivede/pull/18) ([@kirangadhave](https://github.com/kirangadhave))
- testing actions [#15](https://github.com/kirangadhave/interactivede/pull/15) ([@kirangadhave](https://github.com/kirangadhave))
- Testing kernel comms [#1](https://github.com/kirangadhave/interactivede/pull/1) ([@kirangadhave](https://github.com/kirangadhave))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/kirangadhave/interactivede/graphs/contributors?from=2023-01-16&to=2023-03-06&type=c))

[@github-actions](https://github.com/search?q=repo%3Akirangadhave%2Finteractivede+involves%3Agithub-actions+updated%3A2023-01-16..2023-03-06&type=Issues) | [@kirangadhave](https://github.com/search?q=repo%3Akirangadhave%2Finteractivede+involves%3Akirangadhave+updated%3A2023-01-16..2023-03-06&type=Issues)
